@@ -1,6 +1,6 @@
 package main
 
-import "./special_variable_macros"
+import "swigtests/special_variable_macros"
 
 func main() {
 	name := special_variable_macros.NewName()
@@ -16,10 +16,19 @@ func main() {
 	if special_variable_macros.TestMary(name) != "SWIGTYPE_p_NameWrap" {
 		panic("test failed")
 	}
+	if special_variable_macros.TestJames(name) != "SWIGTYPE_Name" {
+		panic("test failed")
+	}
 	if special_variable_macros.TestJim(name) != "multiname num" {
 		panic("test failed")
 	}
 	if special_variable_macros.TestJohn(special_variable_macros.NewPairIntBool(10, false)) != 123 {
 		panic("test failed")
 	}
+	if special_variable_macros.MakeStringInt("stringint", 999) != "stringint" {
+		panic("test failed")
+	}
+	if special_variable_macros.ProvideStringInt(999) != "1000" {
+		panic("test failed")
+	}
 }
