@@ -202,7 +202,7 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 1602 "./CParse/parser.y"
+#line 1604 "./CParse/parser.y"
 
   const char  *id;
   List  *bases;
@@ -210,6 +210,11 @@ union YYSTYPE
     String *val;
     String *rawval;
     int     type;
+    /* The type code for the argument when the top level operator is unary.
+     * This is useful because our grammar parses cases such as (7)*6 as a
+     * cast applied to an unary operator.
+     */
+    int	    unary_arg_type;
     String *qualifier;
     String *refqualifier;
     String *bitfield;
@@ -250,7 +255,7 @@ union YYSTYPE
   int           intvalue;
   Node         *node;
 
-#line 254 "CParse/parser.h"
+#line 259 "CParse/parser.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
